@@ -8,13 +8,13 @@ from ircutils import bot
 from six import text_type
 from six.moves import configparser
 
-RE_WHITESPACE = re.compile('\s+', re.UNICODE)
 debug = True
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 
 class RedditBot(bot.SimpleBot):
+    MSG_FORMAT = u'{shortlink} New post to /r/{subreddit} by {author}: {title}'
     IGNORE_EVENTS = set(('CONN_CONNECT', 'CTCP_VERSION', 'JOIN', 'KICK',
                          'MODE', 'NICK', 'PART', 'PING', 'PRIVMSG', 'QUIT',
                          'RPL_BOUNCE', 'RPL_CREATED', 'RPL_ENDOFMOTD',
@@ -47,9 +47,21 @@ class RedditBot(bot.SimpleBot):
         print('(PRIVATE %r) <%s> %s' % (self.server, event.source,
                                         event.message))
 
+    def announce(self, submission, channel):
+        msg = self.MSG_FORMAT.format(
+            url=submission.url,
+            permalink=submission.permalink,
+            shortlink=submission.short_link,
+            subreddit=text_type(submission.subreddit),
+            author=text_type(submission.author),
+            title=submission.title).encode('utf-8')
+        msg = re.sub('\s+', ' ', msg).strip()
+        if debug:
+            print(msg)
+        self.send_message(channel, msg)
+
 
 class RedditUpdater(object):
-    MSG_FORMAT = '%s New post to /r/%s by %s: %s'
     MSG_LIMIT = 3
     class_reddit = None
 
@@ -81,15 +93,8 @@ class RedditUpdater(object):
             submissions = submissions[-self.MSG_LIMIT:]
         self.previous = submissions[0]
         for submission in reversed(submissions):
-            msg = (self.MSG_FORMAT % (submission.short_link,
-                                      text_type(submission.subreddit),
-                                      text_type(submission.author),
-                                      submission.title)).encode('utf-8')
-            msg = re.sub('\s+', ' ', msg).strip()
-            if debug:
-                print(msg)
             for server_bot, channel in self.associations:
-                server_bot.send_message(channel, msg)
+                server_bot.announce(submission, channel)
 
 
 class Runner(object):
@@ -106,6 +111,8 @@ class Runner(object):
             raise Exception('Could not find settings file.')
         RedditUpdater.class_reddit = praw.Reddit(config.get('DEFAULT',
                                                             'reddit_agent'))
+        if config.has_option('DEFAULT', 'check_time'):
+            self.CHECK_TIME = int(config.get('DEFAULT', 'check_time'))
         for server in config.sections():
             self.parse_server(server, dict(config.items(server)))
 
@@ -129,7 +136,10 @@ class Runner(object):
         bot.connect(items['irc_host'], int(items['irc_port']),
                     channel=channels,
                     use_ssl=use_ssl)
-        bot.identify(items['irc_pswd'])
+        if 'irc_msg' in items:
+            bot.MSG_FORMAT = text_type(items['irc_msg'])
+        if 'irc_pswd' in items:
+            bot.identify(items['irc_pswd'])
 
     def run(self):
         now = time.time()
